//模板字典
export interface TemplateDictVO{
    description: string;
    id: number;
    name: string;
    createTime?: number;
}

//模板字典详情
export interface TemplateDictDetailVO {
    dictId: number;
    dictSort: number;
    id: number;
    label: string;
    value: string;
    createTime: number;
}


/**
 * TemplateInfoVO，模板数据
 */
export interface TemplateInfoVO {
    /**
     * 背景ids
     */
    backgroupIds?: number[];
    /**
     * 类别
     */
    catePubId: string;
    /**
     * 每天最大刊登量
     */
    dayMaxPublishNumber?: number;
    /**
     * 模版id
     */
    id: number;
    /**
     * 图片信息
     */
    imageInfo: TemplateImgVO[];
    /**
     * 物流渠道
     */
    logistics: TemplateLogisticsVO[];
    /**
     * 素材组ids
     */
    materialClassifyIds?: number[];
    /**
     * 店铺最大上架数量
     */
    maxPrintCount: number;
    /**
     * 产品价格
     */
    originalPrice: number;
    /**
     * 平台编码
     */
    platformCode: string;
    /**
     * 单价折扣
     */
    priceDiscount?: number;
    /**
     * 变种比例
     */
    proportion?: number;
    /**
     * 模板备注
     */
    remark?: string;
    /**
     * 店铺id
     */
    shopId: number;
    /**
     * 类目属性
     */
    templateAttrs: TemplateAttrInfoVO[];
    templateDimension: TemplateDimensionVO;
    /**
     * 模板名称编码
     */
    templateName: string;
    templateProduct: TemplateProductVO;
    templateSkuSpace?: TemplateSkuSpaceVO;
    /**
     * 图片信息
     */
    videoInfo: TemplateVideoVO[];
}

/**
 * TemplateImgVO，模板图片信息
 */
export interface TemplateImgVO {
    /**
     * 图片id
     */
    id?: number;
    /**
     * 图片Url信息
     */
    url: string;
}

/**
 * TemplateLogisticsVO，模板物流通道
 */
export interface TemplateLogisticsVO {
    /**
     * 是否为此项目启用通道（0.否 1.是）
     */
    enabled: number;
    /**
     * 是否为买家支付运费（0.否 1.是）
     */
    isFree?: number;
    /**
     * 频道的 ID
     */
    logisticId: number;
    /**
     * 运费
     */
    shippingFee?: number;
    /**
     * 大小 ID
     */
    sizeId?: number;
}

/**
 * TemplateAttrInfoVO，模板属性信息封装VO
 */
export interface TemplateAttrInfoVO {
    templateAttr: TemplateAttrVO;
    /**
     * 模板属性值信息
     */
    templateAttrVals: TemplateAttrValVO[];
}

/**
 * TemplateAttrVO，模板属性信息
 */
export interface TemplateAttrVO {
    /**
     * 属性ID
     */
    attrId: number;
    /**
     * 属性名称
     */
    attrName: string;
}

/**
 * TemplateAttrValVO，模板属性值信息
 */
export interface TemplateAttrValVO {
    /**
     * 属性值ID
     */
    attrValId: number;
    /**
     * 属性值名称
     */
    attrValName: string;
    /**
     * 价值单位（仅限定量属性）
     */
    valueUnit?: string;
}

/**
 * TemplateDimensionVO，模板包装尺寸
 */
export interface TemplateDimensionVO {
    /**
     * 包装高度，单位为厘米
     */
    packageHeight: number;
    /**
     * 包装长度，单位为厘米
     */
    packageLength: number;
    /**
     * 包装宽度，单位为厘米
     */
    packageWidth: number;
    /**
     * 重量,单位为千克
     */
    weight: number;
}

/**
 * TemplateProductVO，模板产品信息
 */
export interface TemplateProductVO {
    /**
     * 品牌ID
     */
    brandId?: number;
    /**
     * 品牌名称
     */
    brandName?: string;
    /**
     * 项目的状况，可以是二手的或新的
     */
    conditionVal?: string;
    /**
     * 保证发货数量
     */
    daysToShip?: number;
    /**
     * 描述数据字典ID
     */
    description: string;
    /**
     * 产品Id
     */
    id: number;
    /**
     * 商品是否为预购商品(0.否  1.是)
     */
    isPreOrder: number;
    /**
     * 产品名称数据字典ID
     */
    itemName: string;
    /**
     * 产品状态
     */
    itemStatus: string;
}

/**
 * TemplateSkuSpaceVO，模板sku
 */
export interface TemplateSkuSpaceVO {
    /**
     * 销售数量
     */
    inventory?: number;
    /**
     * 价格
     */
    originalPrice?: number;
    /**
     * 尺码
     */
    sizeId?: number;
    /**
     * 批发价格
     */
    templateWholesale?: TemplateWholesaleVO[];
}

/**
 * TemplateWholesaleVO，模板批发价格
 */
export interface TemplateWholesaleVO {
    /**
     * 此层的最大计数
     */
    maxCount: number;
    /**
     * 此层的最小计数
     */
    minCount: number;
    /**
     * 价格
     */
    unitPrice: number;
}

/**
 * TemplateVideoVO，模板视频信息
 */
export interface TemplateVideoVO {
    /**
     * 视频id
     */
    id?: number;
    /**
     * 视频信息
     */
    url: string;
}


//模板分页请求参数
export interface TemplateInfoPageReqVO extends PageParam {
    /**
     * 背景id(a,b,c)
     */
    backgroupIds?: string;
    /**
     * 类目id
     */
    catePubId?: string;
    /**
     * 创建时间
     */
    createTime?: string[];
    /**
     * 素材id(a,b,c)
     */
    materialClassifyIds?: string;
    /**
     * 最大上刊数量
     */
    maxPrintCount?: number;
    /**
     * 平台编码
     */
    platformCode?: string;
    /**
     * 变种比例
     */
    proportion?: number;
    /**
     * 备注
     */
    remark?: string;
    /**
     * 店铺id
     */
    shopId?: number;
    /**
     * 模板名称
     */
    templateName?: string;
}


export interface TemplateDictPageReqVO extends PageParam {
    createTime?: string[];
    description?: string;
    name?: string;
}

export interface TemplateDictDetaiPageReqVO extends PageParam {
    createTime?: string[];
    dictId?: number;
    dictSort?: number;
    label?: string;
    value?: string;
}
